@@ -1,25 +1,29 @@
+import re
 from enum import Enum
 from typing import Type, cast, Iterable, List, Optional
 from collections_extended import RangeMap
 from pydantic import BaseModel, Field
 from pymultirole_plugins.v1.processor import ProcessorParameters, ProcessorBase
 from pymultirole_plugins.v1.schema import Document, Annotation
+import icu
 
 
 class ConsolidationType(str, Enum):
+    default = 'default'
     linker = 'linker'
     unknown = 'unknown'
     unknown_only = 'unknown_only'
-    kill = 'kill'
 
 
 class ConsolidateParameters(ProcessorParameters):
-    type: ConsolidationType = Field(ConsolidationType.unknown, description="""Type of consolidation, use<br />
+    type: ConsolidationType = Field(ConsolidationType.default, description="""Type of consolidation, use<br />
+    - *default* deduplicate and if overlap keep only the longest match<br />
     - *linker* to retain only known entities<br />
-    - *unknown* to retain all but prepending `unknown_` to the label name of unknwon entities<br />
-    - *unknown_only* to retain only unknown entities prepending `unknown_` to their label name<br />
-    - *kill* to kill entities which label name is defined in `kill_label`""")
+    - *unknown* to retain all but prepending `unknown_` to the label name of unknown entities<br />
+    - *unknown_only* to retain only unknown entities prepending `unknown_` to their label name<br />""")
     kill_label: Optional[str] = Field(None, description="Label name of the kill list")
+    unknown_prefix: Optional[str] = Field("Unknown ",
+                                          description="String to prepend to the label of 'unknown' entities")
 
 
 class ConsolidateProcessor(ProcessorBase):
@@ -37,10 +41,11 @@ class ConsolidateProcessor(ProcessorBase):
                 anns = self.filter_annotations(document, params.kill_label)
                 if params.type in [ConsolidationType.unknown_only, ConsolidationType.unknown]:
                     for a in anns:
+                        unknown_labelName = sanitize_label(params.unknown_prefix + a.labelName)
                         if not has_knowledge(a):
-                            a.labelName = "unknown_" + a.labelName
+                            a.labelName = unknown_labelName
                             if a.label:
-                                a.label = "Unknown " + a.label
+                                a.label = params.unknown_prefix + a.label
                     if params.type == ConsolidationType.unknown_only:
                         anns = [a for a in anns if not has_knowledge(a)]
                 elif params.type == ConsolidationType.linker:
@@ -88,3 +93,19 @@ class ConsolidateProcessor(ProcessorBase):
                             target.properties = props
         result = sorted([ann for ann in result if ann.labelName != kill_label], key=lambda ann: ann.start)
         return result
+
+
+nonAlphanum = re.compile(r'[\W]+', flags=re.ASCII)
+underscores = re.compile("_{2,}", flags=re.ASCII)
+trailingAndLeadingUnderscores = re.compile(r"^_+|_+\$", flags=re.ASCII)
+# see http://userguide.icu-project.org/transforms/general
+transliterator = icu.Transliterator.createInstance(
+    "Any-Latin; NFD; [:Nonspacing Mark:] Remove; NFC; Latin-ASCII; Lower;", icu.UTransDirection.FORWARD)
+
+
+def sanitize_label(string):
+    result = transliterator.transliterate(string)
+    result = re.sub(nonAlphanum, "_", result)
+    result = re.sub(underscores, "_", result)
+    result = re.sub(trailingAndLeadingUnderscores, "", result)
+    return result
