@@ -99,7 +99,7 @@ def test_consolidate_unknown_only(original_doc):
     assert original_groups_label is not None
     doc = original_doc.copy(deep=True)
     processor = ConsolidateProcessor()
-    parameters = ConsolidateParameters(type=ConsolidationType.unknown_only)
+    parameters = ConsolidateParameters(type=ConsolidationType.unknown_only, unknown_prefix="Candidate ")
     docs = processor.process([doc], parameters)
     consolidated: Document = docs[0]
     # consolidated_groups_lexicon = group_annotations(consolidated, by_lexicon)
@@ -107,7 +107,7 @@ def test_consolidate_unknown_only(original_doc):
     assert len(original_doc.annotations) > len(consolidated.annotations)
     knowns_unknowns = defaultdict(list)
     for label, anns in consolidated_groups_label.items():
-        k = 'unknown' if label.startswith("unknown_") else "known"
+        k = 'unknown' if label.startswith("candidate_") else "known"
         knowns_unknowns[k].extend(anns)
     assert len(knowns_unknowns["known"]) == 0
     assert len(knowns_unknowns["unknown"]) > 0
@@ -120,7 +120,7 @@ def test_kill():
         doc = json.load(fin)
         original_doc = Document(**doc)
         processor = ConsolidateProcessor()
-        parameters = ConsolidateParameters(type=ConsolidationType.kill, kill_label='killed')
+        parameters = ConsolidateParameters(type=ConsolidationType.default, kill_label='killed')
         docs = processor.process([original_doc.copy(deep=True)], parameters)
         consolidated: Document = docs[0]
         assert len(original_doc.annotations) > len(consolidated.annotations)
